==> phpnuke-5.5.tgz: www/phpnuke/html/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","ISO-8859-1");
define("_SEARCH","Buscar");
define("_LOGIN","Login");
define("_WRITES", "escribi");
define("_POSTEDON","Enviado el");
define("_NICKNAME","Nickname");
define("_PASSWORD","Password");
define("_WELCOMETO","Bienvenido a");
define("_EDIT","Editar");
define("_DELETE","Borrar");
define("_POSTEDBY","Enviado por");
define("_READS","Lecturas");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Volver Atrs</a> ]");
define("_COMMENTS","Cometarios");
define("_PASTARTICLES","Artculos Pasados");
define("_OLDERARTICLES","Artculos Viejos");
define("_BY","por");
define("_ON","el");
define("_LOGOUT","Salir");
define("_WAITINGCONT","Contenido Esperando");
define("_SUBMISSIONS","Envos");
define("_WREVIEWS","Reviews");
define("_WLINKS","Enlaces");
define("_EPHEMERIDS","Efemrides");
define("_ONEDAY","Tal da como hoy...");
define("_ASREGISTERED","Todava no tienes una cuenta? Puedes <a href=\"modules.php?name=Your_Account\">crearte una</a>. Como usuario registrado tendrs ventajas como seleccionar la apariencia de la pgina, configurar los comentarios y enviar los comentarios con tu nombre.");
define("_MENUFOR","Men de");
define("_NOBIGSTORY","Hoy an no hay una Gran Historia.");
define("_BIGSTORY","La Historia ms leda hoy:");
define("_SURVEY","Encuesta");
define("_POLLS","Encuestas");
define("_PCOMMENTS","Comentarios:");
define("_RESULTS","Resultados");
define("_HREADMORE","Leer ms...");
define("_CURRENTLY","Actualmente hay");
define("_GUESTS","invitados,");
define("_MEMBERS","miembro(s) conectado(s).");
define("_YOUARELOGGED","Ests conectado como");
define("_YOUHAVE","Tienes");
define("_PRIVATEMSG","mensaje(s) privado(s).");
define("_YOUAREANON","Eres un usuario annimo. Puedes registrarte <a href=\"modules.php?name=Your_Account\">aqu</a>");
define("_NOTE","Nota:");
define("_ADMIN","Admin:");
define("_WERECEIVED","Hemos recibido");
define("_PAGESVIEWS","impresiones desde");
define("_TOPIC","Tpico");
define("_UDOWNLOADS","Descargas");
define("_VOTE","voto");
define("_VOTES","votos");
define("_MVIEWADMIN","Ver: Slo Administradores");
define("_MVIEWUSERS","Ver: Slo Usuarios Registrados");
define("_MVIEWANON","Ver: Slo Usuarios Annimos");
define("_MVIEWALL","Ver: Todos los Visitantes");
define("_EXPIRELESSHOUR","Caducidad: menos de una hora");
define("_EXPIREIN","Caduca en");
define("_HTTPREFERERS","HTTP Referers");
define("_UNLIMITED","Ilimitado");
define("_HOURS","Horas");
define("_RSSPROBLEM","Actualmente hay un problema con los titulares de este sitio");
define("_SELECTLANGUAGE","Seleccionar Idioma");
define("_SELECTGUILANG","Selecciona Idioma de la Interfaz:");
define("_NONE","Ninguno");
define("_BLOCKPROBLEM","<center>Hay un problema con este bloque.</center>");
define("_BLOCKPROBLEM2","<center>En este momento no existe contenido para este bloque.</center>");
define("_MODULENOTACTIVE","Disculpa, este Mdulo no est Activo!");
define("_NOACTIVEMODULES","Mdulos Inactivos");
define("_FORADMINTESTS","(Para Pruebas)");
define("_BBFORUMS","Foros");
define("_ACCESSDENIED", "Acceso Denegado");
define("_RESTRICTEDAREA", "Ests intentando entrar en rea restringida.");
define("_MODULEUSERS", "Lo sentimos pero esta seccin de nuestro sitio es slo para <i>Usuarios Registrados</i><br><br>Puedes registrarte de forma gratuta <a href=\"modules.php?name=Your_Account&op=new_user\">aqu</a>, luego podrs<br>acceder a esta seccin sin restricciones. Gracias.<br><br>");
define("_MODULESADMINS", "Lo sentimos pero esta seccin de nuestro sitio es slo para <i>Administradores</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
define("_DATESTRING","%A, %d %B a las %T");
define("_DATESTRING2","%A, %d %B");
define("_DATE","Date");
define("_HOUR","Hour");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","ISO-8859-1");
define("_SEARCH","Buscar");
define("_LOGIN","Login");
define("_WRITES", "escribi");
define("_POSTEDON","Enviado el");
define("_NICKNAME","Nickname");
define("_PASSWORD","Password");
define("_WELCOMETO","Bienvenido a");
define("_EDIT","Editar");
define("_DELETE","Borrar");
define("_POSTEDBY","Enviado por");
define("_READS","Lecturas");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Volver Atrs</a> ]");
define("_COMMENTS","Cometarios");
define("_PASTARTICLES","Artculos Pasados");
define("_OLDERARTICLES","Artculos Viejos");
define("_BY","por");
define("_ON","el");
define("_LOGOUT","Salir");
define("_WAITINGCONT","Contenido Esperando");
define("_SUBMISSIONS","Envos");
define("_WREVIEWS","Reviews");
define("_WLINKS","Enlaces");
define("_EPHEMERIDS","Efemrides");
define("_ONEDAY","Tal da como hoy...");
define("_ASREGISTERED","Todava no tienes una cuenta? Puedes <a href=\"modules.php?name=Your_Account\">crearte una</a>. Como usuario registrado tendrs ventajas como seleccionar la apariencia de la pgina, configurar los comentarios y enviar los comentarios con tu nombre.");
define("_MENUFOR","Men de");
define("_NOBIGSTORY","Hoy an no hay una Gran Historia.");
define("_BIGSTORY","La Historia ms leda hoy:");
define("_SURVEY","Encuesta");
define("_POLLS","Encuestas");
define("_PCOMMENTS","Comentarios:");
define("_RESULTS","Resultados");
define("_HREADMORE","Leer ms...");
define("_CURRENTLY","Actualmente hay");
define("_GUESTS","invitados,");
define("_MEMBERS","miembro(s) conectado(s).");
define("_YOUARELOGGED","Ests conectado como");
define("_YOUHAVE","Tienes");
define("_PRIVATEMSG","mensaje(s) privado(s).");
define("_YOUAREANON","Eres un usuario annimo. Puedes registrarte <a href=\"modules.php?name=Your_Account\">aqu</a>");
define("_NOTE","Nota:");
define("_ADMIN","Admin:");
define("_WERECEIVED","Hemos recibido");
define("_PAGESVIEWS","impresiones desde");
define("_TOPIC","Tpico");
define("_UDOWNLOADS","Descargas");
define("_VOTE","voto");
define("_VOTES","votos");
define("_MVIEWADMIN","Ver: Slo Administradores");
define("_MVIEWUSERS","Ver: Slo Usuarios Registrados");
define("_MVIEWANON","Ver: Slo Usuarios Annimos");
define("_MVIEWALL","Ver: Todos los Visitantes");
define("_EXPIRELESSHOUR","Caducidad: menos de una hora");
define("_EXPIREIN","Caduca en");
define("_HTTPREFERERS","HTTP Referers");
define("_UNLIMITED","Ilimitado");
define("_HOURS","Horas");
define("_RSSPROBLEM","Actualmente hay un problema con los titulares de este sitio");
define("_SELECTLANGUAGE","Seleccionar Idioma");
define("_SELECTGUILANG","Selecciona Idioma de la Interfaz:");
define("_NONE","Ninguno");
define("_BLOCKPROBLEM","<center>Hay un problema con este bloque.</center>");
define("_BLOCKPROBLEM2","<center>En este momento no existe contenido para este bloque.</center>");
define("_MODULENOTACTIVE","Disculpa, este Mdulo no est Activo!");
define("_NOACTIVEMODULES","Mdulos Inactivos");
define("_FORADMINTESTS","(Para Pruebas)");
define("_BBFORUMS","Foros");
define("_ACCESSDENIED", "Acceso Denegado");
define("_RESTRICTEDAREA", "Ests intentando entrar en rea restringida.");
define("_MODULEUSERS", "Lo sentimos pero esta seccin de nuestro sitio es slo para <i>Usuarios Registrados</i><br><br>Puedes registrarte de forma gratuta <a href=\"modules.php?name=Your_Account&op=new_user\">aqu</a>, luego podrs<br>acceder a esta seccin sin restricciones. Gracias.<br><br>");
define("_MODULESADMINS", "Lo sentimos pero esta seccin de nuestro sitio es slo para <i>Administradores</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","Hay un gran problema aqu: No tenemos un pgina de Inicio!!!");
define("_ADDAHOME","Agregar un mdulo en el Home");
define("_HOMEPROBLEMUSER","Existe un problema en nuestro sitio. Por favor intenta ms tarde.");
define("_MORENEWS","Ms en la Seccin de Noticias");
define("_ALLCATEGORIES","Todas las Categoras");
define("_DATESTRING","%A, %d %B a las %T");
define("_DATESTRING2","%A, %d %B");
define("_DATE","Fecha");
define("_HOUR","Hora");
define("_UMONTH","Mes");
define("_YEAR","Ao");
define("_JANUARY","Enero");
define("_FEBRUARY","Febrero");
define("_MARCH","Marzo");
define("_APRIL","Abril");
define("_MAY","Mayo");
define("_JUNE","Junio");
define("_JULY","Julio");
define("_AUGUST","Agosto");
define("_SEPTEMBER","Septiembre");
define("_OCTOBER","Octubre");
define("_NOVEMBER","Noviembre");
define("_DECEMBER","Diciembre");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>
